{% extends "mvp/list.inc.html" %}
{% load i18n %}
{% load common %}

{% block table-headings %}
	<th>{% trans "Language" %}</th>
	<th class="hidden-xs hidden-sm">{% trans "Headline" %}</th>
{% endblock %}

{% block table-columns %}
	<td>
		{% if change_perm in object_perms %}
			<a href="{{ obj.urls.edit }}">{{ obj.locale|language_name }}</a>&nbsp;
		{% else %}
			<span>{{ obj.locale|language_name }}</span>
		{% endif %}

        <span class="label label-default">{{ obj.locale }}</span>
	</td>
	<td class="hidden-xs hidden-sm">{{ obj.headline }}</td>
{% endblock %}

{% block empty-row-colspan %}3{% endblock %}

{% block row-buttons-items %}
    <li role="presentation">
        <a role="button" href="{{ obj.get_absolute_url }}" target="_blank">
			<i class="fa fa-eye fa-fw"></i>
			{% trans "View on web" %}
        </a>
    </li>
{{ block.super }}
{% endblock row-buttons-items %}
