{% extends "touchtechnology/admin/list.html" %}
{% load i18n %}

{% block table-headings %}
	<th>{% trans "Label" %}</th>
	<th class="hidden-xs">{% trans "Source" %}</th>
	<th class="hidden-xs hidden-sm">{% trans "Destination" %}</th>
{% endblock %}

{% block table-columns %}
	<td>
		{% if change_perm in object_perms %}
			<a href="{{ edit_url }}">{{ obj.label|default:obj.source_url }}</a>
		{% else %}
			{{ obj.label|default:obj.source_url }}
		{% endif %}
	</td>
	<td class="hidden-xs">{{ obj.source_url }}</td>
	<td class="hidden-xs hidden-sm">{{ obj.destination_url }}</td>
{% endblock %}
