{% extends "registration/base.html" %}
{% load i18n %}

{% block content %}
	<h1>{% block page_title %}{% trans "Password change successful" %}{% endblock %}</h1>

	<p>{% trans "Your password was changed." %}</p>

	<div class="btn-group">
		<a class="btn btn-default" role="button" href="/">
			<i class="fa fa-home"></i>
			{% trans "Return to site" %}
		</a>

		{% if user.is_staff %}
			<a class="btn btn-default" role="button" href="{% url 'admin:index' %}">
				<i class="fa fa-cog"></i>
				{% trans "Return to admin" %}
			</a>
		{% endif %}
	</div>
{% endblock %}
