{% extends "registration/base.html" %}
{% load i18n %}

{% block content %}
	<h1>{% block page_title %}{% trans "Password reset successful" %}{% endblock %}</h1>

	<p>{% trans "We've e-mailed you instructions for setting your password to the e-mail address you submitted. You should be receiving it shortly." %}</p>
{% endblock %}
