{% extends "registration/base.html" %}
{% load i18n %}
{% load common %}

{% block content %}
	<h1>{% block page_title %}{% trans "Password change" %}{% endblock %}</h1>

	<p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

	<form class="fields" action="" method="post">
		{% csrf_token %}

		{% field form.old_password %}
		{% field form.new_password1 %}
		{% field form.new_password2 %}

		<div class="btn-group">
			<button type="submit">
				<i class="fa fa-play-circle"></i>
				{% trans "Change my password" %}
			</button>

			{% if user.is_staff %}
				<a class="btn btn-default" role="button" href="{% url 'admin:index' %}">
					<i class="fa fa-cog"></i>
					{% trans "Return to admin" %}
				</a>
			{% endif %}
		</div>
	</form>
{% endblock %}
